==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DeviceInfo.java <==
package com.example.model;

/**
 * Model for DeviceInfo
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "DeviceInfo", description = "Model for DeviceInfo")
@javax.xml.bind.annotation.XmlRootElement(name = "DeviceInfo")
public class DeviceInfo implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String browser = null;
	private java.lang.String country = null;
	private java.lang.String geolocation = null;
	private java.lang.String ip = null;
	private java.lang.String ipLocation = null;
	private java.lang.String isp = null;
	private java.lang.String os = null;
	private java.lang.Boolean vpn = null;
	
	/**
	 */
	public DeviceInfo browser(java.lang.String browser) {
		setBrowser(browser);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("browser")
	@javax.validation.constraints.NotNull
	public java.lang.String getBrowser() {
		return this.browser;
	}
	public void setBrowser(java.lang.String browser) {
		this.browser = browser;
	}
	
	/**
	 */
	public DeviceInfo country(java.lang.String country) {
		setCountry(country);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("country")
	public java.lang.String getCountry() {
		return this.country;
	}
	public void setCountry(java.lang.String country) {
		this.country = country;
	}
	
	/**
	 */
	public DeviceInfo geolocation(java.lang.String geolocation) {
		setGeolocation(geolocation);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("geolocation")
	public java.lang.String getGeolocation() {
		return this.geolocation;
	}
	public void setGeolocation(java.lang.String geolocation) {
		this.geolocation = geolocation;
	}
	
	/**
	 */
	public DeviceInfo ip(java.lang.String ip) {
		setIp(ip);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("ip")
	public java.lang.String getIp() {
		return this.ip;
	}
	public void setIp(java.lang.String ip) {
		this.ip = ip;
	}
	
	/**
	 */
	public DeviceInfo ipLocation(java.lang.String ipLocation) {
		setIpLocation(ipLocation);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("ip_location")
	public java.lang.String getIpLocation() {
		return this.ipLocation;
	}
	public void setIpLocation(java.lang.String ipLocation) {
		this.ipLocation = ipLocation;
	}
	
	/**
	 */
	public DeviceInfo isp(java.lang.String isp) {
		setIsp(isp);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("isp")
	public java.lang.String getIsp() {
		return this.isp;
	}
	public void setIsp(java.lang.String isp) {
		this.isp = isp;
	}
	
	/**
	 */
	public DeviceInfo os(java.lang.String os) {
		setOs(os);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("os")
	public java.lang.String getOs() {
		return this.os;
	}
	public void setOs(java.lang.String os) {
		this.os = os;
	}
	
	/**
	 */
	public DeviceInfo vpn(java.lang.Boolean vpn) {
		setVpn(vpn);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("vpn")
	public java.lang.Boolean getVpn() {
		return this.vpn;
	}
	public void setVpn(java.lang.Boolean vpn) {
		this.vpn = vpn;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DeviceInfo deviceInfo = (DeviceInfo) o;
		return java.util.Objects.equals(this.browser, deviceInfo.browser)
				&& java.util.Objects.equals(this.country, deviceInfo.country)
				&& java.util.Objects.equals(this.geolocation, deviceInfo.geolocation)
				&& java.util.Objects.equals(this.ip, deviceInfo.ip)
				&& java.util.Objects.equals(this.ipLocation, deviceInfo.ipLocation)
				&& java.util.Objects.equals(this.isp, deviceInfo.isp)
				&& java.util.Objects.equals(this.os, deviceInfo.os)
				&& java.util.Objects.equals(this.vpn, deviceInfo.vpn);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.browser, this.country, this.geolocation, this.ip, this.ipLocation, this.isp, this.os, this.vpn);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DeviceInfo {\n");
		
		sb.append("    browser: ").append(toIndentedString(this.browser)).append("\n");
		sb.append("    country: ").append(toIndentedString(this.country)).append("\n");
		sb.append("    geolocation: ").append(toIndentedString(this.geolocation)).append("\n");
		sb.append("    ip: ").append(toIndentedString(this.ip)).append("\n");
		sb.append("    ipLocation: ").append(toIndentedString(this.ipLocation)).append("\n");
		sb.append("    isp: ").append(toIndentedString(this.isp)).append("\n");
		sb.append("    os: ").append(toIndentedString(this.os)).append("\n");
		sb.append("    vpn: ").append(toIndentedString(this.vpn)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DeviceInfo.java <==
package com.example.model;

/**
 * Model for DeviceInfo
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "DeviceInfo", description = "Model for DeviceInfo")
@javax.xml.bind.annotation.XmlRootElement(name = "DeviceInfo")
public class DeviceInfo implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String browser = null;
	private java.lang.String country = null;
	private java.lang.String geolocation = null;
	private java.lang.String ip = null;
	private java.lang.String ipLocation = null;
	private java.lang.String isp = null;
	private java.lang.String os = null;
	private java.lang.Boolean vpn = null;
	
	/**
	 */
	public DeviceInfo browser(java.lang.String browser) {
		setBrowser(browser);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "browser")
	@com.fasterxml.jackson.annotation.JsonProperty("browser")
	@javax.validation.constraints.NotNull
	public java.lang.String getBrowser() {
		return this.browser;
	}
	public void setBrowser(java.lang.String browser) {
		this.browser = browser;
	}
	
	/**
	 */
	public DeviceInfo country(java.lang.String country) {
		setCountry(country);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "country")
	@com.fasterxml.jackson.annotation.JsonProperty("country")
	public java.lang.String getCountry() {
		return this.country;
	}
	public void setCountry(java.lang.String country) {
		this.country = country;
	}
	
	/**
	 */
	public DeviceInfo geolocation(java.lang.String geolocation) {
		setGeolocation(geolocation);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "geolocation")
	@com.fasterxml.jackson.annotation.JsonProperty("geolocation")
	public java.lang.String getGeolocation() {
		return this.geolocation;
	}
	public void setGeolocation(java.lang.String geolocation) {
		this.geolocation = geolocation;
	}
	
	/**
	 */
	public DeviceInfo ip(java.lang.String ip) {
		setIp(ip);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "ip")
	@com.fasterxml.jackson.annotation.JsonProperty("ip")
	public java.lang.String getIp() {
		return this.ip;
	}
	public void setIp(java.lang.String ip) {
		this.ip = ip;
	}
	
	/**
	 */
	public DeviceInfo ipLocation(java.lang.String ipLocation) {
		setIpLocation(ipLocation);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "ip_location")
	@com.fasterxml.jackson.annotation.JsonProperty("ip_location")
	public java.lang.String getIpLocation() {
		return this.ipLocation;
	}
	public void setIpLocation(java.lang.String ipLocation) {
		this.ipLocation = ipLocation;
	}
	
	/**
	 */
	public DeviceInfo isp(java.lang.String isp) {
		setIsp(isp);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "isp")
	@com.fasterxml.jackson.annotation.JsonProperty("isp")
	public java.lang.String getIsp() {
		return this.isp;
	}
	public void setIsp(java.lang.String isp) {
		this.isp = isp;
	}
	
	/**
	 */
	public DeviceInfo os(java.lang.String os) {
		setOs(os);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "os")
	@com.fasterxml.jackson.annotation.JsonProperty("os")
	public java.lang.String getOs() {
		return this.os;
	}
	public void setOs(java.lang.String os) {
		this.os = os;
	}
	
	/**
	 */
	public DeviceInfo vpn(java.lang.Boolean vpn) {
		setVpn(vpn);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "vpn")
	@com.fasterxml.jackson.annotation.JsonProperty("vpn")
	public java.lang.Boolean getVpn() {
		return this.vpn;
	}
	public void setVpn(java.lang.Boolean vpn) {
		this.vpn = vpn;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DeviceInfo deviceInfo = (DeviceInfo) o;
		return java.util.Objects.equals(this.browser, deviceInfo.browser)
				&& java.util.Objects.equals(this.country, deviceInfo.country)
				&& java.util.Objects.equals(this.geolocation, deviceInfo.geolocation)
				&& java.util.Objects.equals(this.ip, deviceInfo.ip)
				&& java.util.Objects.equals(this.ipLocation, deviceInfo.ipLocation)
				&& java.util.Objects.equals(this.isp, deviceInfo.isp)
				&& java.util.Objects.equals(this.os, deviceInfo.os)
				&& java.util.Objects.equals(this.vpn, deviceInfo.vpn);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.browser, this.country, this.geolocation, this.ip, this.ipLocation, this.isp, this.os, this.vpn);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DeviceInfo {\n");
		
		sb.append("    browser: ").append(toIndentedString(this.browser)).append("\n");
		sb.append("    country: ").append(toIndentedString(this.country)).append("\n");
		sb.append("    geolocation: ").append(toIndentedString(this.geolocation)).append("\n");
		sb.append("    ip: ").append(toIndentedString(this.ip)).append("\n");
		sb.append("    ipLocation: ").append(toIndentedString(this.ipLocation)).append("\n");
		sb.append("    isp: ").append(toIndentedString(this.isp)).append("\n");
		sb.append("    os: ").append(toIndentedString(this.os)).append("\n");
		sb.append("    vpn: ").append(toIndentedString(this.vpn)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
